==> huaweicloudsdksecmaster-3.1.79-py2.py3-none-any.whl: huaweicloudsdksecmaster/v2/model/create_playbook_version_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreatePlaybookVersionRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'project_id': 'str',
        'workspace_id': 'str',
        'playbook_id': 'str',
        'body': 'CreatePlaybookVersionInfo'
    }

    attribute_map = {
        'project_id': 'project_id',
        'workspace_id': 'workspace_id',
        'playbook_id': 'playbook_id',
        'body': 'body'
    }

    def __init__(self, project_id=None, workspace_id=None, playbook_id=None, body=None):
        """CreatePlaybookVersionRequest

        The model defined in huaweicloud sdk

        :param project_id: 项目ID
        :type project_id: str
        :param workspace_id: 工作空间ID
        :type workspace_id: str
        :param playbook_id: 剧本ID
        :type playbook_id: str
        :param body: Body of the CreatePlaybookVersionRequest
        :type body: :class:`huaweicloudsdksecmaster.v2.CreatePlaybookVersionInfo`
        """
        
        

        self._project_id = None
        self._workspace_id = None
        self._playbook_id = None
        self._body = None
        self.discriminator = None

        self.project_id = project_id
        self.workspace_id = workspace_id
        self.playbook_id = playbook_id
        if body is not None:
            self.body = body

    @property
    def project_id(self):
        """Gets the project_id of this CreatePlaybookVersionRequest.

        项目ID

        :return: The project_id of this CreatePlaybookVersionRequest.
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this CreatePlaybookVersionRequest.

        项目ID

        :param project_id: The project_id of this CreatePlaybookVersionRequest.
        :type project_id: str
        """
        self._project_id = project_id

    @property
    def workspace_id(self):
        """Gets the workspace_id of this CreatePlaybookVersionRequest.

        工作空间ID

        :return: The workspace_id of this CreatePlaybookVersionRequest.
        :rtype: str
        """
        return self._workspace_id

    @workspace_id.setter
    def workspace_id(self, workspace_id):
        """Sets the workspace_id of this CreatePlaybookVersionRequest.

        工作空间ID

        :param workspace_id: The workspace_id of this CreatePlaybookVersionRequest.
        :type workspace_id: str
        """
        self._workspace_id = workspace_id

    @property
    def playbook_id(self):
        """Gets the playbook_id of this CreatePlaybookVersionRequest.

        剧本ID

        :return: The playbook_id of this CreatePlaybookVersionRequest.
        :rtype: str
        """
        return self._playbook_id

    @playbook_id.setter
    def playbook_id(self, playbook_id):
        """Sets the playbook_id of this CreatePlaybookVersionRequest.

        剧本ID

        :param playbook_id: The playbook_id of this CreatePlaybookVersionRequest.
        :type playbook_id: str
        """
        self._playbook_id = playbook_id

    @property
    def body(self):
        """Gets the body of this CreatePlaybookVersionRequest.

        :return: The body of this CreatePlaybookVersionRequest.
        :rtype: :class:`huaweicloudsdksecmaster.v2.CreatePlaybookVersionInfo`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this CreatePlaybookVersionRequest.

        :param body: The body of this CreatePlaybookVersionRequest.
        :type body: :class:`huaweicloudsdksecmaster.v2.CreatePlaybookVersionInfo`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreatePlaybookVersionRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdksecmaster-3.1.146-py2.py3-none-any.whl: huaweicloudsdksecmaster/v2/model/create_playbook_version_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreatePlaybookVersionRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'project_id': 'str',
        'workspace_id': 'str',
        'playbook_id': 'str',
        'body': 'CreatePlaybookVersionInfo'
    }

    attribute_map = {
        'project_id': 'project_id',
        'workspace_id': 'workspace_id',
        'playbook_id': 'playbook_id',
        'body': 'body'
    }

    def __init__(self, project_id=None, workspace_id=None, playbook_id=None, body=None):
        r"""CreatePlaybookVersionRequest

        The model defined in huaweicloud sdk

        :param project_id: 项目ID
        :type project_id: str
        :param workspace_id: 工作空间ID
        :type workspace_id: str
        :param playbook_id: 剧本ID
        :type playbook_id: str
        :param body: Body of the CreatePlaybookVersionRequest
        :type body: :class:`huaweicloudsdksecmaster.v2.CreatePlaybookVersionInfo`
        """
        
        

        self._project_id = None
        self._workspace_id = None
        self._playbook_id = None
        self._body = None
        self.discriminator = None

        self.project_id = project_id
        self.workspace_id = workspace_id
        self.playbook_id = playbook_id
        if body is not None:
            self.body = body

    @property
    def project_id(self):
        r"""Gets the project_id of this CreatePlaybookVersionRequest.

        项目ID

        :return: The project_id of this CreatePlaybookVersionRequest.
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        r"""Sets the project_id of this CreatePlaybookVersionRequest.

        项目ID

        :param project_id: The project_id of this CreatePlaybookVersionRequest.
        :type project_id: str
        """
        self._project_id = project_id

    @property
    def workspace_id(self):
        r"""Gets the workspace_id of this CreatePlaybookVersionRequest.

        工作空间ID

        :return: The workspace_id of this CreatePlaybookVersionRequest.
        :rtype: str
        """
        return self._workspace_id

    @workspace_id.setter
    def workspace_id(self, workspace_id):
        r"""Sets the workspace_id of this CreatePlaybookVersionRequest.

        工作空间ID

        :param workspace_id: The workspace_id of this CreatePlaybookVersionRequest.
        :type workspace_id: str
        """
        self._workspace_id = workspace_id

    @property
    def playbook_id(self):
        r"""Gets the playbook_id of this CreatePlaybookVersionRequest.

        剧本ID

        :return: The playbook_id of this CreatePlaybookVersionRequest.
        :rtype: str
        """
        return self._playbook_id

    @playbook_id.setter
    def playbook_id(self, playbook_id):
        r"""Sets the playbook_id of this CreatePlaybookVersionRequest.

        剧本ID

        :param playbook_id: The playbook_id of this CreatePlaybookVersionRequest.
        :type playbook_id: str
        """
        self._playbook_id = playbook_id

    @property
    def body(self):
        r"""Gets the body of this CreatePlaybookVersionRequest.

        :return: The body of this CreatePlaybookVersionRequest.
        :rtype: :class:`huaweicloudsdksecmaster.v2.CreatePlaybookVersionInfo`
        """
        return self._body

    @body.setter
    def body(self, body):
        r"""Sets the body of this CreatePlaybookVersionRequest.

        :param body: The body of this CreatePlaybookVersionRequest.
        :type body: :class:`huaweicloudsdksecmaster.v2.CreatePlaybookVersionInfo`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreatePlaybookVersionRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
